Index: /issm/trunk/src/c/modules/PointCloudFindNeighborsx/PointCloudFindNeighborsxt.cpp
===================================================================
--- /issm/trunk/src/c/modules/PointCloudFindNeighborsx/PointCloudFindNeighborsxt.cpp	(revision 7648)
+++ /issm/trunk/src/c/modules/PointCloudFindNeighborsx/PointCloudFindNeighborsxt.cpp	(revision 7649)
@@ -13,5 +13,4 @@
 	int     my_thread;
 	int     num_threads;
-	
 	double* x;
 	double* y;
@@ -46,5 +45,5 @@
 
 	/*Loop over the nodes*/
-	if (my_thread==0) printf("      interpolation progress:   %5.2lf %%",0.0);
+	if (my_thread==0) printf("      loop progress:   %5.2lf %%",0.0);
 
 	for (i=i0;i<i1;i++){
@@ -63,6 +62,6 @@
 
 				/*insert value and go to the next point*/
-				if (!already[i]) VecSetValue(flags,i,1,INSERT_VALUES);
-				if (!already[j])  VecSetValue(flags,j,2,INSERT_VALUES);
+				if(!already[i]) VecSetValue(flags,i,1,INSERT_VALUES);
+				if(!already[j]) VecSetValue(flags,j,2,INSERT_VALUES);
 				already[i]=true;
 				already[j]=true;
@@ -75,4 +74,3 @@
 	/*Free ressources:*/
 	xfree((void**)&already);
-
 }
Index: /issm/trunk/src/m/model/divergence.m
===================================================================
--- /issm/trunk/src/m/model/divergence.m	(revision 7648)
+++ /issm/trunk/src/m/model/divergence.m	(revision 7649)
@@ -1,4 +1,7 @@
 function div=divergence(md,a,b)
-%DIVERGENCE    return divergence of [a;b] vector, using model's triangulation.
+%DIVERGENCE - divergence of [a;b] vector, using model's triangulation.
+%
+%   Usage:
+%      div=divergence(md,a,b)
 
 if (md.dim==2),
Index: /issm/trunk/src/mex/PointCloudFindNeighbors/PointCloudFindNeighbors.cpp
===================================================================
--- /issm/trunk/src/mex/PointCloudFindNeighbors/PointCloudFindNeighbors.cpp	(revision 7648)
+++ /issm/trunk/src/mex/PointCloudFindNeighbors/PointCloudFindNeighbors.cpp	(revision 7649)
@@ -25,5 +25,4 @@
 	CheckNumMatlabArguments(nlhs,NLHS,nrhs,NRHS,__FUNCT__,&PointCloudFindNeighborsUsage);
 
-	
 	/*Fetch inputs: */
 	FetchData(&x,&nods,NULL,XHANDLE);
@@ -40,5 +39,4 @@
 	/*end module: */
 	MODULEEND();
-
 }
 
@@ -49,5 +47,5 @@
 	printf("      x,y: list of points.\n");
 	printf("      mindistance: minimum distance that should exist between points in the cloud.\n");
-	printf("      multithread: run multithreaded or not. with multithreads, flags can get 1 and 2 values in duplicatges.\n");
+	printf("      multithread: run multithreaded or not. with multithreads, flags can get 1 and 2 values in duplicates.\n");
 	printf("      flags: array of flags (flag==1 means point is within mindistance of another point)\n");
 	printf("\n");

Index: /issm/trunk/src/m/model/bedslope.m
===================================================================
--- /issm/trunk/src/m/model/bedslope.m	(revision 7648)
+++ /issm/trunk/src/m/model/bedslope.m	(revision 7649)
@@ -1,7 +1,7 @@
-function [bx,by,b]=slope(md)
-%SLOPE - compute the bed slope
+function [bx,by,b]=bedslope(md)
+%BEDSLOPE - compute the bed slope
 %
 %   Usage:
-%      [bx,by,s]=slope(md)
+%      [bx,by,s]=bedslope(md)
 
 %load some variables (it is much faster if the variab;es are loaded from md once for all) 